==> static-compat-qt6-base-6.10.0-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6WaylandClient/Qt6QWaylandFullScreenShellV1IntegrationPluginDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

set(QWaylandFullScreenShellV1IntegrationPlugin_FOUND TRUE)

# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_QWaylandFullScreenShellV1IntegrationPlugin_third_party_deps "Wayland\;FALSE\;\;\;")
_qt_internal_find_third_party_dependencies("QWaylandFullScreenShellV1IntegrationPlugin" __qt_QWaylandFullScreenShellV1IntegrationPlugin_third_party_deps)
unset(__qt_QWaylandFullScreenShellV1IntegrationPlugin_third_party_deps)

set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_QWaylandFullScreenShellV1IntegrationPlugin_target_deps "Qt6Core\;6.10.0;Qt6Gui\;6.10.0;Qt6WaylandClient\;6.10.0")
set(__qt_QWaylandFullScreenShellV1IntegrationPlugin_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/..;${_qt_cmake_dir}")
_qt_internal_find_qt_dependencies("QWaylandFullScreenShellV1IntegrationPlugin" __qt_QWaylandFullScreenShellV1IntegrationPlugin_target_deps
                                  __qt_QWaylandFullScreenShellV1IntegrationPlugin_find_dependency_paths)
unset(__qt_QWaylandFullScreenShellV1IntegrationPlugin_target_deps)
unset(__qt_QWaylandFullScreenShellV1IntegrationPlugin_find_dependency_paths)

if(__qt_${target}_missing_deps)
    set(QWaylandFullScreenShellV1IntegrationPlugin_FOUND FALSE)
endif()

==> static-compat-qt6-base-6.10.1-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6WaylandClient/Qt6QWaylandFullScreenShellV1IntegrationPluginDependencies.cmake <==
# Copyright (C) 2024 The Qt Company Ltd.
# SPDX-License-Identifier: BSD-3-Clause

set(QWaylandFullScreenShellV1IntegrationPlugin_FOUND TRUE)

# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(__qt_QWaylandFullScreenShellV1IntegrationPlugin_third_party_deps "Wayland\;FALSE\;\;\;")
if(__qt_QWaylandFullScreenShellV1IntegrationPlugin_third_party_deps)
    _qt_internal_find_third_party_dependencies("QWaylandFullScreenShellV1IntegrationPlugin" __qt_QWaylandFullScreenShellV1IntegrationPlugin_third_party_deps)
endif()
unset(__qt_QWaylandFullScreenShellV1IntegrationPlugin_third_party_deps)

set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(__qt_QWaylandFullScreenShellV1IntegrationPlugin_target_deps "Qt6Core\;6.10.1;Qt6Gui\;6.10.1;Qt6WaylandClient\;6.10.1")
set(__qt_QWaylandFullScreenShellV1IntegrationPlugin_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/..;${_qt_cmake_dir}")
if(__qt_QWaylandFullScreenShellV1IntegrationPlugin_target_deps)
    _qt_internal_find_qt_dependencies("QWaylandFullScreenShellV1IntegrationPlugin" __qt_QWaylandFullScreenShellV1IntegrationPlugin_target_deps
                                      __qt_QWaylandFullScreenShellV1IntegrationPlugin_find_dependency_paths)
endif()
unset(__qt_QWaylandFullScreenShellV1IntegrationPlugin_target_deps)
unset(__qt_QWaylandFullScreenShellV1IntegrationPlugin_find_dependency_paths)

if(__qt_${target}_missing_deps)
    set(QWaylandFullScreenShellV1IntegrationPlugin_FOUND FALSE)
endif()
